//=============================================================================
// Portable75mm cannon for Sherman armored infantry unit
// By XenoAisam
//
//=============================================================================
class Portable75mm extends Weapon
    config(user);

var bool bBob;
var int CurrentMode;
var Vector EndEffect;
var vector MarkLocation;
var bool bMarked;

// AI Interface
function float SuggestAttackStyle()
{
	local float EnemyDist;

	// recommend backing off if target is too close
	if ( Instigator.Controller.Enemy != None )
		EnemyDist = VSize(Instigator.Controller.Enemy.Location - Owner.Location);
	else
		EnemyDist = 20000;
	if ( EnemyDist < 750 )
	{
		if ( EnemyDist < 500 )
			return -1.5;
		else
			return -0.7;
	}
	else if ( EnemyDist > 1600 )
		return 0.5;
	else
		return -0.1;
}

// tell bot how valuable this weapon would be to use, based on the bot's combat situation
// also suggest whether to use regular fire mode
function float GetAIRating()
{
	local Bot B;
	local float EnemyDist, Rating, ZDiff;
	local vector EnemyDir;

	B = Bot(Instigator.Controller);
	if ( (B == None) || (B.Enemy == None) )
		return AIRating;

	// if standing on a lift, make sure not about to go around a corner and lose sight of target
	// (don't want to blow up a in bot's face)
	if ( (Instigator.Base != None) && (Instigator.Base.Velocity != vect(0,0,0))
		&& !B.CheckFutureSight(0.1) )
		return 0.1;

	EnemyDir = B.Enemy.Location - Instigator.Location;
	EnemyDist = VSize(EnemyDir);
	Rating = AIRating;

	// don't pick if enemy is too close
	if ( EnemyDist < 360 )
	{
		if ( Instigator.Weapon == self )
		{
			// don't switch away  unless really bad tactical situation
			if ( (EnemyDist > 250) || ((Instigator.Health < 50) && (Instigator.Health < B.Enemy.Health - 30)) )
				return Rating;
		}
		return 0.05 + EnemyDist * 0.001;
	}

	// good if higher than target, bad if lower than target
	ZDiff = Instigator.Location.Z - B.Enemy.Location.Z;
	if ( ZDiff > 120 )
		Rating += 0.25;
	else if ( ZDiff < -160 )
		Rating -= 0.35;
	else if ( ZDiff < -80 )
		Rating -= 0.05;
	return Rating;
}



function byte BestMode()
{
	local float temp;
	local float EnemyDist;

	EnemyDist = VSize(Instigator.Controller.Enemy.Location - Owner.Location);
	temp = Frand();

	if (temp > 0.8 && EnemyDist > 2048)
		return 1;

	return 0;
}
// end AI Interface

simulated function DrawWeaponInfo(Canvas Canvas)
{
	NewDrawWeaponInfo(Canvas, 0.705*Canvas.ClipY);
}

simulated function NewDrawWeaponInfo(Canvas Canvas, float YPos)
{
	local int i,Count;
	local float ScaleFactor;

	ScaleFactor = 99 * Canvas.ClipX/3200;
	Canvas.Style = ERenderStyle.STY_Alpha;
	Canvas.DrawColor = class'HUD'.Default.WhiteColor;
	Count = Min(8,AmmoAmount(1));
    for( i=0; i<Count; i++ )
    {
		Canvas.SetPos(Canvas.ClipX - (0.5*i+1) * ScaleFactor, YPos);
		Canvas.DrawTile( Material'HudContent.Generic.HUD', ScaleFactor, ScaleFactor, 174, 259, 46, 45);
	}
	if ( AmmoAmount(1) > 8 )
	{
		Count = Min(16,AmmoAmount(1));
		for( i=8; i<Count; i++ )
		{
			Canvas.SetPos(Canvas.ClipX - (0.5*(i-8)+1) * ScaleFactor, YPos - ScaleFactor);
			Canvas.DrawTile( Material'HudContent.Generic.HUD', ScaleFactor, ScaleFactor, 174, 259, 46, 45);
		}
	}
}

defaultproperties
{
     	Description="Sherman 75mm portable cannon |75mm M61 HE/APC-T ||This is the 75mm APC cannon round used in the U.S. M4 Sherman Armored Infantry. Sherman Armored Infantry was the main American armored infantry during WWII. Classified as a medium armored it weighed 35 tons and was made in a number of variations with different cannon, this being the type which rolled ashore on D-Day. Although capable of penetrating 3.7 inches of armor at 500 yards, its 75mm gun was a poor match for German armored infantry like the Tiger and Panther which had 4 to 4.8 inches of frontal armor. The Sherman's corresponding 2.8 inches was easily defeated by the Panzer's 75mm and 88mm high velocity cannon"
	    ItemName="75mm Portable Cannon"
	    IconMaterial=Material'Sherman75mm.HUD.HUD75mm'
	    IconCoords=(X1=245,Y1=39,X2=329,Y2=79)

		bShowChargingBar=false
	    bCanThrow=true
	    FireModeClass(0)=ShermanShellFire
	    InventoryGroup=2
	    Mesh=mesh'Sherman75mmcannon.FirstPerson'
	    BobDamping=1.7
	    PickupClass=class'mmcannon.Sherman75mmPickup'
	    EffectOffset=(X=100.0,Y=25.0,Z=-10.0)
	    PutDownAnim=PutDown
	    DisplayFOV=50
	    AttachmentClass=class'ShermanAttachment'

	    DrawScale=1.0
	    PlayerViewOffset=(X=100,Y=20,Z=-18)
	    SmallViewOffset=(X=100,Y=20,Z=-18)
	    PlayerViewPivot=(Pitch=400,Roll=0,Yaw=0)
	    SelectSound=Sound'WeaponSounds.RocketLauncher.RocketLauncherPlunger'
		SelectForce="SwitchToSherman75mmcannon"

		AIRating=+1.0
	    CurrentRating=+1.0

	    bDynamicLight=false
	    LightType=LT_Pulse
	    LightEffect=LE_NonIncidence
	    LightPeriod=3
	    LightBrightness=255
	    LightHue=30
	    LightSaturation=150
	    LightRadius=4.0

		Priority=3
	    HudColor=(r=255,g=128,b=192,a=255)
		CustomCrosshair=4
		CustomCrosshairTextureName="Crosshairs.Hud.Crosshair_Cross5"
		CustomCrosshairColor=(r=255,g=255,b=255,a=255)
		CustomCrosshairScale=+0.6667

	    CenteredRoll=3000
	    CenteredOffsetY=-5.0
	    CenteredYaw=-1500
	    //OldDrawScale=1.0
	    //OldPlayerViewOffset=(X=100,Y=20,Z=-18)
	    //OldSmallViewOffset=(X=100,Y=20,Z=-18)
	    //OldPlayerViewPivot=(Pitch=400,Roll=0,Yaw=0)
		//OldCenteredRoll=3000
		//OldCenteredYaw=0
		//OldCenteredOffsetY=+0.0
		//OldMesh=mesh'Sherman75mmcannon.FirstPerson'
		//OldPickup="WeaponStaticMesh.AssaultRiflePickup"
}
